# Botocore Documentation

Documentation for botocore can be found [here](https://docs.aws.amazon.com/botocore/latest/)

## Generating Documentation

Sphinx is used for documentation. You can generate HTML locally with the
following:

```
$ pip install -r requirements-docs.txt
$ cd docs
$ make html
```
